/**
 * Unboxed primitive types.
 *
 * We use boxed primitive types where possible, to achieve nominal typing for extra type safety. However, TSOA does not
 * recognise these, so we provide unboxed variants here that we can attach OpenAPI specification metadata to.
 */
export declare type IgnoreMeUnboxed = never;
/**
 * User ID from your application, to help organize uploaded files.
 * @example "user_id_from_your_app"
 * @minLength 1
 * @maxLength 255
 * @pattern ^\S.*?\S$
 */
export declare type CustomUserIdUnboxed = string;
/**
 * Upload User ID.
 * @example "BC8048E8-A6F4-40CD-BFA2-1081049AA1AB"
 * @minLength 36
 * @maxLength 36
 * @pattern ^\S.*?\S$
 */
export declare type UserIdUnboxed = string;
/**
 * Upload Account ID.
 * @example "A623uY2RX"
 * @minLength 9
 * @maxLength 9
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type AccountIdUnboxed = string;
/**
 * File ID.
 * @example "A623uY2RXvnNq1vZ80fY32f"
 * @minLength 23
 * @maxLength 23
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type FileIdUnboxed = string;
/**
 * Size in bytes.
 * @example 43182
 * @isInt
 * @minimum 0
 */
export declare type SizeInBytesUnboxed = number;
/**
 * Size in bytes (big).
 * @example "856974744186387529544875589443785995421"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\d*$
 */
export declare type BigSizeInBytesUnboxed = string;
/**
 * File tag, to help organize uploaded files.
 * @example "images/profile"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-z0-9\.,/=_+-]*$
 */
export declare type FileTagUnboxed = string;
/**
 * File MIME type.
 * @example "image/jpeg"
 * @minLength 3
 * @maxLength 255
 * @pattern ^[a-z0-9]+/[a-z0-9+\-._]+$
 */
export declare type MimeTypeUnboxed = string;
/**
 * File name.
 * @example "example.jpg"
 * @minLength 1
 * @maxLength 255
 * @pattern ^.+$
 */
export declare type FileNameUnboxed = string;
/**
 * File ETag.
 * @example "33a64df551425fcc55e4d42a148795d9f25f89d4"
 * @minLength 1
 * @maxLength 255
 * @pattern ^\S*$
 */
export declare type ETagUnboxed = string;
/**
 * Number of parts the file will be uploaded in.
 * @example 12
 * @isInt
 * @minimum 1
 */
export declare type FilePartCountUnboxed = number;
/**
 * Index of an uploadable file part.
 * @example 7
 * @isInt
 * @minimum 0
 */
export declare type UploadPartIndexUnboxed = number;
/**
 * Pre-signed upload URL for this part.
 * @example "https://...long-url...x-id=PutObject"
 * @minLength 10
 */
export declare type PreSignedUploadUrlUnboxed = string;
/**
 * Domain name.
 * @example "localhost"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-z0-9-\.]*$
 */
export declare type DomainNameUnboxed = string;
/**
 * JSON Web Token (JWT).
 * @example "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJ4In0.fiX9xWK-9af81KNXzUT_PARqLr9S43OS5iZI7MvLAYk"
 * @pattern ^[a-zA-Z0-9\-_]+?\.[a-zA-Z0-9\-_]+?\.([a-zA-Z0-9\-_]+)?$
 */
export declare type JwtUnboxed = string;
/**
 * First name of a person.
 * @example "Mark"
 * @minLength 1
 * @maxLength 35
 * @pattern ^\S.*?\S$
 */
export declare type FirstNameUnboxed = string;
/**
 * Last name of a person.
 * @example "Smith"
 * @minLength 1
 * @maxLength 35
 * @pattern ^\S.*?\S$
 */
export declare type LastNameUnboxed = string;
/**
 * Email address.
 * @example "mark.smith\u0040example.com"
 * @minLength 1
 * @maxLength 254
 * @pattern ^\S+\x40\S+\.\S+$
 */
export declare type EmailAddressUnboxed = string;
/**
 * Organization name.
 * @example "Acme Corp"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\S.*?\S$
 */
export declare type OrganizationNameUnboxed = string;
/**
 * Department name.
 * @example "Software Development"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\S.*?\S$
 */
export declare type DepartmentNameUnboxed = string;
/**
 * Seconds.
 * @example 60
 * @isInt
 * @minimum 0
 */
export declare type SecondsUnboxed = number;
/**
 * Milliseconds.
 * @example 1000
 * @isInt
 * @minimum 0
 */
export declare type MillisecondsUnboxed = number;
/**
 * Epoch milliseconds (since midnight 1 January 1970, UTC).
 * @example 1615680311115
 * @isInt
 * @minimum 0
 */
export declare type EpochMillisUnboxed = number;
/**
 * Description or notes about an API key.
 * @example "Production API key"
 * @minLength 1
 * @maxLength 50
 * @pattern ^\S.*?\S$
 */
export declare type ApiKeyDescriptionUnboxed = string;
/**
 * Public API key (can be used in frontend code).
 * @example "public_A623uY2RvnNq1vZ80fYgGyhKN0U7xt"
 * @minLength 37
 * @maxLength 37
 * @pattern ^public_[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type PublicApiKeyUnboxed = string;
/**
 * Secret API key (do not use in frontend code).
 * @example "secret_A623uY2RvkUy789gT8jHaPLmNd89qa"
 * @minLength 37
 * @maxLength 37
 * @pattern ^secret_[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type SecretApiKeyUnboxed = string;
/**
 * API key.
 * @example "secret_A623uY2RvkUy789gT8jHaPLmNd89qa"
 * @minLength 37
 * @maxLength 37
 * @pattern ^(public|secret)_[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type ApiKeyUnboxed = string;
/**
 * API key type.
 * @example "secret"
 * @pattern ^(public|secret)$
 */
export declare type ApiKeyTypeUnboxed = "public" | "secret";
/**
 * Username of package maintainer on NPM.
 * @example "upload-io"
 * @minLength 1
 * @maxLength 50
 * @pattern ^[0-9A-Za-z-_.]*$
 */
export declare type NpmUsernameUnboxed = string;
/**
 * NPM package name.
 * @example "upload-compression-plugin"
 * @minLength 1
 * @maxLength 100
 * @pattern ^[0-9A-Za-z-_.\x40\/]*$
 */
export declare type NpmPackageNameUnboxed = string;
/**
 * Semantic version.
 * @example "1.2.0"
 * @minLength 1
 * @maxLength 50
 * @pattern ^([0-9]+)\.([0-9]+)\.([0-9]+)(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+[0-9A-Za-z-]+)?$
 */
export declare type SemanticVersionUnboxed = string;
/**
 * Description for an Upload Plugin.
 * @example "Archives, compresses and decompresses files."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S.*?\S$
 */
export declare type PluginDescriptionUnboxed = string;
/**
 * Category for a transformation template.
 * @example "Image"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S.*?\S$
 */
export declare type TemplateCategoryUnboxed = string;
/**
 * Codename for a template that is unique within the scope of a specific plugin version.
 * @example "compress"
 * @minLength 1
 * @maxLength 100
 * @pattern ^.*?$
 */
export declare type TemplateKeyUnboxed = string;
/**
 * Name for a transformation template.
 * @example "Compress a file"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S.*?\S$
 */
export declare type TemplateNameUnboxed = string;
/**
 * Description for a transformation template.
 * @example "Compresses the file into a ZIP at a given compression level."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S.*?\S$
 */
export declare type TemplateDescriptionUnboxed = string;
/**
 * Label for a transformation template parameter.
 * @example "Compression format"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S.*?\S$
 */
export declare type TemplateParamLabelUnboxed = string;
/**
 * Transformation definition ID.
 * @example "A623uY2RXvnNq1vZ80fY"
 * @minLength 8
 * @maxLength 8
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export declare type TransformationDefinitionIdUnboxed = string;
/**
 * Description given to a transformation.
 * @example "Compresses the file into a ZIP at level 9 compression."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S.*?\S$
 */
export declare type TransformationDescriptionUnboxed = string;
/**
 * MIME type scope for a transformation definition.
 * @example "*"
 * @minLength 1
 * @maxLength 255
 * @pattern ^(?:\*|[a-z0-9]+\/(?:[a-z0-9+\-._]+|[a-z0-9+\-._]*\*))$
 */
export declare type TransformationMimeScopeUnboxed = string;
/**
 * File tag scope for a transformation definition.
 * @example "*"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-z0-9\.,/=_+-]*\*?$
 */
export declare type TransformationTagScopeUnboxed = string;
/**
 * Identifies the location to save/load transformed files to/from.
 * @example "compressed-files-v1"
 * @minLength 8
 * @maxLength 8
 * @pattern ^[a-zA-Z0-9-]*$
 */
export declare type CacheIdUnboxed = string;
/**
 * Transformation URL slug (excludes the leading forward-slash).
 * @example "resize:800x600"
 * @minLength 1
 * @maxLength 100
 * @pattern ^[a-zA-Z0-9-_.+=\x40~:%]*$
 */
export declare type TransformationUrlSlugUnboxed = string;
/**
 * @minItems 1
 */
export declare type NonEmptyArrayUnboxed<T> = T[];
/**
 * @uniqueItems true
 * @minItems 1
 */
export declare type NonEmptySetUnboxed<T> = T[];
/**
 * Continuation token (aka pagination cursor).
 * @example "user_id_from_your_app"
 * @minLength 1
 * @maxLength 1000
 * @pattern ^\S.*?\S$
 */
export declare type ContinuationTokenUnboxed = string;
/**
 * Page size (i.e. maximum items to return in a page of results).
 * @example 12
 * @isInt
 * @minimum 3
 * @maximum 20
 */
export declare type PageSizeUnboxed = number;
